#Copyright 2010 Alexander Savi
#
#This file is part of the Inductive Causation scripts.
#
#The Inductive Causation scripts are free software: you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation, either version 3 of the License, or
#(at your option) any later version.
#
#The Inductive Causation scripts are distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with the Inductive Causation scripts.  If not, see <http://www.gnu.org/licenses/>.

icCor <- function(data) {
  nTime <- nrow(data)
  nVar <- ncol(data)
  nPairs <- nrow(combinations(nVar, 2))
  CombiMatrix <- matrix(,,,)
  for (i in 1:(nVar-2)) {
    CombiMatrix[i] <- nrow(combinations(nVar, i))
  }
  nCombi <- sum(CombiMatrix)+1
  CovMatrix <- icCov(data)
  corError <- matrix(0, 1, 1, dimnames=list(c("no. of errors"), c("cor")))
  
  cor <- matrix(, nPairs, nCombi)
  
  PairsList <- list()
  Pairs <- combinations(nVar, 2)
  for (i in 1:nPairs) {
    PairsList[[i]] <- Pairs[i,]
  }
  PairNames <- paste(combinations(nVar, 2)[,1], combinations(nVar, 2)[,2], sep="")
  rownames(cor) <- PairNames
  
  CombiList <- list()
  CombiNames <- character()
  count <- 1
  for(i in 0:(nVar-2)) {
    nCom2 <- choose(nVar, i)
    if(i==0) {
      Combi <- as.matrix(0)
    } else {
      Combi <- combinations(nVar, i)
    }
    
    for(k in 1:nCom2) {
      CombiNames <- c(CombiNames, paste(Combi[k,], sep="", collapse=""))
      CombiList[[count]] <- Combi[k,]
      count <- count + 1
    }
  }
  colnames(cor) <- CombiNames
  
  for (i in 1:nPairs) {
    for (j in 1:nCombi) {
      cortmp <- matrix(, nPairs, nCombi)
      if(length(intersect(PairsList[[i]], CombiList[[j]])) > 0) {
        cor[i,j] <- NA
      } else {
        cortmp[i,j] <- try(round(parcor(CovMatrix[c(PairsList[[i]], CombiList[[j]]), c(PairsList[[i]], CombiList[[j]])]), 3)[1,2], silent=TRUE) #parcor (package ggm) is not compatible with R>=2.15.1, please download 'graph' and 'RBGL' from bioconductor
      }
      
      if(class(cortmp)=="try-error") {
        corError[1, 1] = corError[1, 1] + 1
      } else {
        cor[i,j] <- cortmp[i,j]
      }
    }
  }
  
  if(corError[1, 1] != 0) {
    stop("One or more (partial) correlations could not be calculated correctly.")
  } else {
    return(cor)
  }
}