#Copyright 2010 Alexander Savi
#
#This file is part of the Inductive Causation scripts.
#
#The Inductive Causation scripts are free software: you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation, either version 3 of the License, or
#(at your option) any later version.
#
#The Inductive Causation scripts are distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with the Inductive Causation scripts.  If not, see <http://www.gnu.org/licenses/>.

plotAll <- function(data, alpha=.05) {
	adjM <- icAdj(data, alpha=alpha)
	colM <- icCol(data, alpha=alpha)
	rudM <- icRud(data, alpha=alpha)
	
	g1 <- graph.adjacency(adjM, mode="undirected")
	g2 <- graph.adjacency(colM, mode="directed")
	g3 <- graph.adjacency(rudM, mode="directed")

	V(g1)$color <- V(g2)$color <- V(g3)$color <- "white"
	V(g1)$label.color <- V(g2)$label.color <- V(g3)$label.color <- "black"
	V(g1)$label <- V(g2)$label <- V(g3)$label <- 1:vcount(g1)
	E(g1)$color <- E(g2)$color <- E(g3)$color <- "black"

	set.seed(30)
	l1 <- layout.fruchterman.reingold(g1)
	par(mar=c(1, 1, 3, 1))
	
	layout(matrix(c(1:4), 2, 2, byrow=TRUE))

	nvar <- ncol(data)
	edges <- E(g3)
	tmp <- lapply(edges, lapply, length)
	names(tmp) <- lapply(edges, length)
	nedges <- length(names(tmp))
	if(nedges == 0) {
		plot(g3, layout=l);
		title("Rudimentary Graph")
	} else {
		E(g3)[0:(nedges-1)]$arrow.mode <- "->"

		edges.splitL <- list()
		for (i in 0:(nedges-1))	{
			edges.splitL[[i+1]] <- get.edge(g3, i) + 1 						#iGraph uses [0] as the 'floor', this will be changed in the near future!
		}

		for (i in 1:nvar) {
			for (j in 1:nvar)	{
				if((rudM[i,j] == rudM[j,i]) & (rudM[i,j] == 1)) {
					v1 <- grep(i, edges.splitL) - 1						#iGraph uses [0] as the 'floor', this will be changed in the near future!
					v2 <- grep(j, edges.splitL) - 1						#iGraph uses [0] as the 'floor', this will be changed in the near future!
					settozero <- intersect(v1, v2)
					E(g3)[c(settozero[1], settozero[2])]$arrow.mode <- "-"
				} else {}
			}
		}
		plot(g1, layout=l1)
		title("Adjacencies")
	
		plot(g2, layout=l1)
		title("Colliders")
	
		plot(g3, layout=l1)
		title("Rudimentary Graph")

		textplot("not yet available", cex=1)
		title("Completed Graph")
	}
}